/* graphs.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __GRAPHS_GRAPHS_H__
#define __GRAPHS_GRAPHS_H__

#include <adwaita.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gio/gio.h>
#include <gtk/gtk.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define GRAPHS_TYPE_APPLICATION (graphs_application_get_type ())
#define GRAPHS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_APPLICATION, GraphsApplication))
#define GRAPHS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_APPLICATION, GraphsApplicationClass))
#define GRAPHS_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_APPLICATION))
#define GRAPHS_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_APPLICATION))
#define GRAPHS_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_APPLICATION, GraphsApplicationClass))

typedef struct _GraphsApplication GraphsApplication;
typedef struct _GraphsApplicationClass GraphsApplicationClass;

#define GRAPHS_TYPE_ADD_EQUATION_DIALOG (graphs_add_equation_dialog_get_type ())
#define GRAPHS_ADD_EQUATION_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_ADD_EQUATION_DIALOG, GraphsAddEquationDialog))
#define GRAPHS_ADD_EQUATION_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_ADD_EQUATION_DIALOG, GraphsAddEquationDialogClass))
#define GRAPHS_IS_ADD_EQUATION_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_ADD_EQUATION_DIALOG))
#define GRAPHS_IS_ADD_EQUATION_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_ADD_EQUATION_DIALOG))
#define GRAPHS_ADD_EQUATION_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_ADD_EQUATION_DIALOG, GraphsAddEquationDialogClass))

typedef struct _GraphsAddEquationDialog GraphsAddEquationDialog;
typedef struct _GraphsAddEquationDialogClass GraphsAddEquationDialogClass;
typedef struct _GraphsAddEquationDialogPrivate GraphsAddEquationDialogPrivate;
typedef struct _GraphsApplicationPrivate GraphsApplicationPrivate;

#define GRAPHS_TYPE_WINDOW (graphs_window_get_type ())
#define GRAPHS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_WINDOW, GraphsWindow))
#define GRAPHS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_WINDOW, GraphsWindowClass))
#define GRAPHS_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_WINDOW))
#define GRAPHS_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_WINDOW))
#define GRAPHS_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_WINDOW, GraphsWindowClass))

typedef struct _GraphsWindow GraphsWindow;
typedef struct _GraphsWindowClass GraphsWindowClass;

#define GRAPHS_TYPE_DATA (graphs_data_get_type ())
#define GRAPHS_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_DATA, GraphsData))
#define GRAPHS_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_DATA, GraphsDataClass))
#define GRAPHS_IS_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_DATA))
#define GRAPHS_IS_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_DATA))
#define GRAPHS_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_DATA, GraphsDataClass))

typedef struct _GraphsData GraphsData;
typedef struct _GraphsDataClass GraphsDataClass;

#define GRAPHS_TYPE_STYLE_MANAGER (graphs_style_manager_get_type ())
#define GRAPHS_STYLE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_STYLE_MANAGER, GraphsStyleManager))
#define GRAPHS_STYLE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_STYLE_MANAGER, GraphsStyleManagerClass))
#define GRAPHS_IS_STYLE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_STYLE_MANAGER))
#define GRAPHS_IS_STYLE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_STYLE_MANAGER))
#define GRAPHS_STYLE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_STYLE_MANAGER, GraphsStyleManagerClass))

typedef struct _GraphsStyleManager GraphsStyleManager;
typedef struct _GraphsStyleManagerClass GraphsStyleManagerClass;

#define GRAPHS_TYPE_CANVAS (graphs_canvas_get_type ())
#define GRAPHS_CANVAS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_CANVAS, GraphsCanvas))
#define GRAPHS_CANVAS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_CANVAS, GraphsCanvasClass))
#define GRAPHS_IS_CANVAS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_CANVAS))
#define GRAPHS_IS_CANVAS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_CANVAS))
#define GRAPHS_CANVAS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_CANVAS, GraphsCanvasClass))

typedef struct _GraphsCanvas GraphsCanvas;
typedef struct _GraphsCanvasClass GraphsCanvasClass;
typedef struct _GraphsCanvasPrivate GraphsCanvasPrivate;

#define GRAPHS_TYPE_FITTING_PARAMETER (graphs_fitting_parameter_get_type ())
#define GRAPHS_FITTING_PARAMETER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_FITTING_PARAMETER, GraphsFittingParameter))
#define GRAPHS_FITTING_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_FITTING_PARAMETER, GraphsFittingParameterClass))
#define GRAPHS_IS_FITTING_PARAMETER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_FITTING_PARAMETER))
#define GRAPHS_IS_FITTING_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_FITTING_PARAMETER))
#define GRAPHS_FITTING_PARAMETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_FITTING_PARAMETER, GraphsFittingParameterClass))

typedef struct _GraphsFittingParameter GraphsFittingParameter;
typedef struct _GraphsFittingParameterClass GraphsFittingParameterClass;
typedef struct _GraphsFittingParameterPrivate GraphsFittingParameterPrivate;

#define GRAPHS_TYPE_CURVE_FITTING_DIALOG (graphs_curve_fitting_dialog_get_type ())
#define GRAPHS_CURVE_FITTING_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_CURVE_FITTING_DIALOG, GraphsCurveFittingDialog))
#define GRAPHS_CURVE_FITTING_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_CURVE_FITTING_DIALOG, GraphsCurveFittingDialogClass))
#define GRAPHS_IS_CURVE_FITTING_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_CURVE_FITTING_DIALOG))
#define GRAPHS_IS_CURVE_FITTING_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_CURVE_FITTING_DIALOG))
#define GRAPHS_CURVE_FITTING_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_CURVE_FITTING_DIALOG, GraphsCurveFittingDialogClass))

typedef struct _GraphsCurveFittingDialog GraphsCurveFittingDialog;
typedef struct _GraphsCurveFittingDialogClass GraphsCurveFittingDialogClass;
typedef struct _GraphsCurveFittingDialogPrivate GraphsCurveFittingDialogPrivate;

#define GRAPHS_TYPE_FITTING_PARAMETER_BOX (graphs_fitting_parameter_box_get_type ())
#define GRAPHS_FITTING_PARAMETER_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_FITTING_PARAMETER_BOX, GraphsFittingParameterBox))
#define GRAPHS_FITTING_PARAMETER_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_FITTING_PARAMETER_BOX, GraphsFittingParameterBoxClass))
#define GRAPHS_IS_FITTING_PARAMETER_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_FITTING_PARAMETER_BOX))
#define GRAPHS_IS_FITTING_PARAMETER_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_FITTING_PARAMETER_BOX))
#define GRAPHS_FITTING_PARAMETER_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_FITTING_PARAMETER_BOX, GraphsFittingParameterBoxClass))

typedef struct _GraphsFittingParameterBox GraphsFittingParameterBox;
typedef struct _GraphsFittingParameterBoxClass GraphsFittingParameterBoxClass;
typedef struct _GraphsFittingParameterBoxPrivate GraphsFittingParameterBoxPrivate;
typedef struct _GraphsDataPrivate GraphsDataPrivate;

#define GRAPHS_TYPE_FIGURE_SETTINGS (graphs_figure_settings_get_type ())
#define GRAPHS_FIGURE_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_FIGURE_SETTINGS, GraphsFigureSettings))
#define GRAPHS_FIGURE_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_FIGURE_SETTINGS, GraphsFigureSettingsClass))
#define GRAPHS_IS_FIGURE_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_FIGURE_SETTINGS))
#define GRAPHS_IS_FIGURE_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_FIGURE_SETTINGS))
#define GRAPHS_FIGURE_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_FIGURE_SETTINGS, GraphsFigureSettingsClass))

typedef struct _GraphsFigureSettings GraphsFigureSettings;
typedef struct _GraphsFigureSettingsClass GraphsFigureSettingsClass;

#define GRAPHS_TYPE_EXPORT_FIGURE_DIALOG (graphs_export_figure_dialog_get_type ())
#define GRAPHS_EXPORT_FIGURE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_EXPORT_FIGURE_DIALOG, GraphsExportFigureDialog))
#define GRAPHS_EXPORT_FIGURE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_EXPORT_FIGURE_DIALOG, GraphsExportFigureDialogClass))
#define GRAPHS_IS_EXPORT_FIGURE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_EXPORT_FIGURE_DIALOG))
#define GRAPHS_IS_EXPORT_FIGURE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_EXPORT_FIGURE_DIALOG))
#define GRAPHS_EXPORT_FIGURE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_EXPORT_FIGURE_DIALOG, GraphsExportFigureDialogClass))

typedef struct _GraphsExportFigureDialog GraphsExportFigureDialog;
typedef struct _GraphsExportFigureDialogClass GraphsExportFigureDialogClass;
typedef struct _GraphsExportFigureDialogPrivate GraphsExportFigureDialogPrivate;
typedef struct _GraphsFigureSettingsPrivate GraphsFigureSettingsPrivate;

#define GRAPHS_TYPE_FIGURE_SETTINGS_DIALOG (graphs_figure_settings_dialog_get_type ())
#define GRAPHS_FIGURE_SETTINGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_FIGURE_SETTINGS_DIALOG, GraphsFigureSettingsDialog))
#define GRAPHS_FIGURE_SETTINGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_FIGURE_SETTINGS_DIALOG, GraphsFigureSettingsDialogClass))
#define GRAPHS_IS_FIGURE_SETTINGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_FIGURE_SETTINGS_DIALOG))
#define GRAPHS_IS_FIGURE_SETTINGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_FIGURE_SETTINGS_DIALOG))
#define GRAPHS_FIGURE_SETTINGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_FIGURE_SETTINGS_DIALOG, GraphsFigureSettingsDialogClass))

typedef struct _GraphsFigureSettingsDialog GraphsFigureSettingsDialog;
typedef struct _GraphsFigureSettingsDialogClass GraphsFigureSettingsDialogClass;
typedef struct _GraphsFigureSettingsDialogPrivate GraphsFigureSettingsDialogPrivate;

#define GRAPHS_TYPE_IMPORT_DIALOG (graphs_import_dialog_get_type ())
#define GRAPHS_IMPORT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_IMPORT_DIALOG, GraphsImportDialog))
#define GRAPHS_IMPORT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_IMPORT_DIALOG, GraphsImportDialogClass))
#define GRAPHS_IS_IMPORT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_IMPORT_DIALOG))
#define GRAPHS_IS_IMPORT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_IMPORT_DIALOG))
#define GRAPHS_IMPORT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_IMPORT_DIALOG, GraphsImportDialogClass))

typedef struct _GraphsImportDialog GraphsImportDialog;
typedef struct _GraphsImportDialogClass GraphsImportDialogClass;
typedef struct _GraphsImportDialogPrivate GraphsImportDialogPrivate;

#define GRAPHS_TYPE_ITEM (graphs_item_get_type ())
#define GRAPHS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_ITEM, GraphsItem))
#define GRAPHS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_ITEM, GraphsItemClass))
#define GRAPHS_IS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_ITEM))
#define GRAPHS_IS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_ITEM))
#define GRAPHS_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_ITEM, GraphsItemClass))

typedef struct _GraphsItem GraphsItem;
typedef struct _GraphsItemClass GraphsItemClass;
typedef struct _GraphsItemPrivate GraphsItemPrivate;

#define GRAPHS_TYPE_INLINE_STACK_SWITCHER (graphs_inline_stack_switcher_get_type ())
#define GRAPHS_INLINE_STACK_SWITCHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_INLINE_STACK_SWITCHER, GraphsInlineStackSwitcher))
#define GRAPHS_INLINE_STACK_SWITCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_INLINE_STACK_SWITCHER, GraphsInlineStackSwitcherClass))
#define GRAPHS_IS_INLINE_STACK_SWITCHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_INLINE_STACK_SWITCHER))
#define GRAPHS_IS_INLINE_STACK_SWITCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_INLINE_STACK_SWITCHER))
#define GRAPHS_INLINE_STACK_SWITCHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_INLINE_STACK_SWITCHER, GraphsInlineStackSwitcherClass))

typedef struct _GraphsInlineStackSwitcher GraphsInlineStackSwitcher;
typedef struct _GraphsInlineStackSwitcherClass GraphsInlineStackSwitcherClass;
typedef struct _GraphsInlineStackSwitcherPrivate GraphsInlineStackSwitcherPrivate;

#define GRAPHS_TYPE_ITEM_BOX (graphs_item_box_get_type ())
#define GRAPHS_ITEM_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_ITEM_BOX, GraphsItemBox))
#define GRAPHS_ITEM_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_ITEM_BOX, GraphsItemBoxClass))
#define GRAPHS_IS_ITEM_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_ITEM_BOX))
#define GRAPHS_IS_ITEM_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_ITEM_BOX))
#define GRAPHS_ITEM_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_ITEM_BOX, GraphsItemBoxClass))

typedef struct _GraphsItemBox GraphsItemBox;
typedef struct _GraphsItemBoxClass GraphsItemBoxClass;
typedef struct _GraphsItemBoxPrivate GraphsItemBoxPrivate;

#define GRAPHS_TYPE_SMOOTHEN_DIALOG (graphs_smoothen_dialog_get_type ())
#define GRAPHS_SMOOTHEN_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_SMOOTHEN_DIALOG, GraphsSmoothenDialog))
#define GRAPHS_SMOOTHEN_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_SMOOTHEN_DIALOG, GraphsSmoothenDialogClass))
#define GRAPHS_IS_SMOOTHEN_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_SMOOTHEN_DIALOG))
#define GRAPHS_IS_SMOOTHEN_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_SMOOTHEN_DIALOG))
#define GRAPHS_SMOOTHEN_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_SMOOTHEN_DIALOG, GraphsSmoothenDialogClass))

typedef struct _GraphsSmoothenDialog GraphsSmoothenDialog;
typedef struct _GraphsSmoothenDialogClass GraphsSmoothenDialogClass;
typedef struct _GraphsSmoothenDialogPrivate GraphsSmoothenDialogPrivate;

#define GRAPHS_TYPE_STYLE (graphs_style_get_type ())
#define GRAPHS_STYLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_STYLE, GraphsStyle))
#define GRAPHS_STYLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_STYLE, GraphsStyleClass))
#define GRAPHS_IS_STYLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_STYLE))
#define GRAPHS_IS_STYLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_STYLE))
#define GRAPHS_STYLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_STYLE, GraphsStyleClass))

typedef struct _GraphsStyle GraphsStyle;
typedef struct _GraphsStyleClass GraphsStyleClass;
typedef struct _GraphsStyleManagerPrivate GraphsStyleManagerPrivate;
typedef struct _GraphsStylePrivate GraphsStylePrivate;

#define GRAPHS_TYPE_ADD_STYLE_DIALOG (graphs_add_style_dialog_get_type ())
#define GRAPHS_ADD_STYLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_ADD_STYLE_DIALOG, GraphsAddStyleDialog))
#define GRAPHS_ADD_STYLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_ADD_STYLE_DIALOG, GraphsAddStyleDialogClass))
#define GRAPHS_IS_ADD_STYLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_ADD_STYLE_DIALOG))
#define GRAPHS_IS_ADD_STYLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_ADD_STYLE_DIALOG))
#define GRAPHS_ADD_STYLE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_ADD_STYLE_DIALOG, GraphsAddStyleDialogClass))

typedef struct _GraphsAddStyleDialog GraphsAddStyleDialog;
typedef struct _GraphsAddStyleDialogClass GraphsAddStyleDialogClass;
typedef struct _GraphsAddStyleDialogPrivate GraphsAddStyleDialogPrivate;

#define GRAPHS_TYPE_TRANSFORM_DIALOG (graphs_transform_dialog_get_type ())
#define GRAPHS_TRANSFORM_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GRAPHS_TYPE_TRANSFORM_DIALOG, GraphsTransformDialog))
#define GRAPHS_TRANSFORM_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GRAPHS_TYPE_TRANSFORM_DIALOG, GraphsTransformDialogClass))
#define GRAPHS_IS_TRANSFORM_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GRAPHS_TYPE_TRANSFORM_DIALOG))
#define GRAPHS_IS_TRANSFORM_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GRAPHS_TYPE_TRANSFORM_DIALOG))
#define GRAPHS_TRANSFORM_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GRAPHS_TYPE_TRANSFORM_DIALOG, GraphsTransformDialogClass))

typedef struct _GraphsTransformDialog GraphsTransformDialog;
typedef struct _GraphsTransformDialogClass GraphsTransformDialogClass;
typedef struct _GraphsTransformDialogPrivate GraphsTransformDialogPrivate;
typedef struct _GraphsWindowPrivate GraphsWindowPrivate;

struct _GraphsAddEquationDialog {
	AdwDialog parent_instance;
	GraphsAddEquationDialogPrivate * priv;
};

struct _GraphsAddEquationDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsApplication {
	AdwApplication parent_instance;
	GraphsApplicationPrivate * priv;
};

struct _GraphsApplicationClass {
	AdwApplicationClass parent_class;
};

struct _GraphsCanvas {
	GtkDrawingArea parent_instance;
	GraphsCanvasPrivate * priv;
};

struct _GraphsCanvasClass {
	GtkDrawingAreaClass parent_class;
};

struct _GraphsFittingParameter {
	GObject parent_instance;
	GraphsFittingParameterPrivate * priv;
};

struct _GraphsFittingParameterClass {
	GObjectClass parent_class;
};

struct _GraphsCurveFittingDialog {
	AdwDialog parent_instance;
	GraphsCurveFittingDialogPrivate * priv;
};

struct _GraphsCurveFittingDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsFittingParameterBox {
	GtkBox parent_instance;
	GraphsFittingParameterBoxPrivate * priv;
};

struct _GraphsFittingParameterBoxClass {
	GtkBoxClass parent_class;
};

struct _GraphsData {
	GObject parent_instance;
	GraphsDataPrivate * priv;
};

struct _GraphsDataClass {
	GObjectClass parent_class;
};

struct _GraphsExportFigureDialog {
	AdwDialog parent_instance;
	GraphsExportFigureDialogPrivate * priv;
};

struct _GraphsExportFigureDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsFigureSettings {
	GObject parent_instance;
	GraphsFigureSettingsPrivate * priv;
};

struct _GraphsFigureSettingsClass {
	GObjectClass parent_class;
};

struct _GraphsFigureSettingsDialog {
	AdwDialog parent_instance;
	GraphsFigureSettingsDialogPrivate * priv;
};

struct _GraphsFigureSettingsDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsImportDialog {
	AdwDialog parent_instance;
	GraphsImportDialogPrivate * priv;
};

struct _GraphsImportDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsItem {
	GObject parent_instance;
	GraphsItemPrivate * priv;
};

struct _GraphsItemClass {
	GObjectClass parent_class;
};

struct _GraphsInlineStackSwitcher {
	GtkWidget parent_instance;
	GraphsInlineStackSwitcherPrivate * priv;
};

struct _GraphsInlineStackSwitcherClass {
	GtkWidgetClass parent_class;
};

struct _GraphsItemBox {
	GtkBox parent_instance;
	GraphsItemBoxPrivate * priv;
};

struct _GraphsItemBoxClass {
	GtkBoxClass parent_class;
};

struct _GraphsSmoothenDialog {
	AdwDialog parent_instance;
	GraphsSmoothenDialogPrivate * priv;
};

struct _GraphsSmoothenDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsStyleManager {
	GObject parent_instance;
	GraphsStyleManagerPrivate * priv;
};

struct _GraphsStyleManagerClass {
	GObjectClass parent_class;
};

struct _GraphsStyle {
	GObject parent_instance;
	GraphsStylePrivate * priv;
};

struct _GraphsStyleClass {
	GObjectClass parent_class;
};

struct _GraphsAddStyleDialog {
	AdwDialog parent_instance;
	GraphsAddStyleDialogPrivate * priv;
};

struct _GraphsAddStyleDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsTransformDialog {
	AdwDialog parent_instance;
	GraphsTransformDialogPrivate * priv;
};

struct _GraphsTransformDialogClass {
	AdwDialogClass parent_class;
};

struct _GraphsWindow {
	AdwApplicationWindow parent_instance;
	GraphsWindowPrivate * priv;
};

struct _GraphsWindowClass {
	AdwApplicationWindowClass parent_class;
};

VALA_EXTERN GType graphs_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsApplication, g_object_unref)
VALA_EXTERN void graphs_show_about_dialog (GraphsApplication* application);
VALA_EXTERN void graphs_setup_actions (GraphsApplication* application);
VALA_EXTERN GType graphs_add_equation_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsAddEquationDialog, g_object_unref)
VALA_EXTERN GraphsAddEquationDialog* graphs_add_equation_dialog_new (GraphsApplication* application);
VALA_EXTERN GraphsAddEquationDialog* graphs_add_equation_dialog_construct (GType object_type,
                                                               GraphsApplication* application);
VALA_EXTERN AdwEntryRow* graphs_add_equation_dialog_get_equation (GraphsAddEquationDialog* self);
VALA_EXTERN AdwEntryRow* graphs_add_equation_dialog_get_x_start (GraphsAddEquationDialog* self);
VALA_EXTERN AdwEntryRow* graphs_add_equation_dialog_get_x_stop (GraphsAddEquationDialog* self);
VALA_EXTERN AdwEntryRow* graphs_add_equation_dialog_get_step_size (GraphsAddEquationDialog* self);
VALA_EXTERN AdwEntryRow* graphs_add_equation_dialog_get_item_name (GraphsAddEquationDialog* self);
VALA_EXTERN GSettings* graphs_application_get_settings_child (GraphsApplication* self,
                                                  const gchar* path);
VALA_EXTERN GraphsApplication* graphs_application_new (void);
VALA_EXTERN GraphsApplication* graphs_application_construct (GType object_type);
VALA_EXTERN GType graphs_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsWindow, g_object_unref)
VALA_EXTERN GraphsWindow* graphs_application_get_window (GraphsApplication* self);
VALA_EXTERN void graphs_application_set_window (GraphsApplication* self,
                                    GraphsWindow* value);
VALA_EXTERN GSettings* graphs_application_get_settings (GraphsApplication* self);
VALA_EXTERN void graphs_application_set_settings (GraphsApplication* self,
                                      GSettings* value);
VALA_EXTERN GType graphs_data_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsData, g_object_unref)
VALA_EXTERN GraphsData* graphs_application_get_data (GraphsApplication* self);
VALA_EXTERN void graphs_application_set_data (GraphsApplication* self,
                                  GraphsData* value);
VALA_EXTERN GType graphs_style_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsStyleManager, g_object_unref)
VALA_EXTERN GraphsStyleManager* graphs_application_get_figure_style_manager (GraphsApplication* self);
VALA_EXTERN void graphs_application_set_figure_style_manager (GraphsApplication* self,
                                                  GraphsStyleManager* value);
VALA_EXTERN gboolean graphs_application_get_debug (GraphsApplication* self);
VALA_EXTERN void graphs_application_set_debug (GraphsApplication* self,
                                   gboolean value);
VALA_EXTERN GType graphs_canvas_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsCanvas, g_object_unref)
VALA_EXTERN GraphsCanvas* graphs_canvas_new (void);
VALA_EXTERN GraphsCanvas* graphs_canvas_construct (GType object_type);
VALA_EXTERN gboolean graphs_canvas_get_hide_unselected (GraphsCanvas* self);
VALA_EXTERN void graphs_canvas_set_hide_unselected (GraphsCanvas* self,
                                        gboolean value);
VALA_EXTERN gint graphs_canvas_get_mode (GraphsCanvas* self);
VALA_EXTERN void graphs_canvas_set_mode (GraphsCanvas* self,
                             gint value);
VALA_EXTERN gdouble graphs_canvas_get_min_selected (GraphsCanvas* self);
VALA_EXTERN void graphs_canvas_set_min_selected (GraphsCanvas* self,
                                     gdouble value);
VALA_EXTERN gdouble graphs_canvas_get_max_selected (GraphsCanvas* self);
VALA_EXTERN void graphs_canvas_set_max_selected (GraphsCanvas* self,
                                     gdouble value);
VALA_EXTERN GType graphs_fitting_parameter_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsFittingParameter, g_object_unref)
VALA_EXTERN GraphsFittingParameter* graphs_fitting_parameter_new (void);
VALA_EXTERN GraphsFittingParameter* graphs_fitting_parameter_construct (GType object_type);
VALA_EXTERN const gchar* graphs_fitting_parameter_get_name (GraphsFittingParameter* self);
VALA_EXTERN void graphs_fitting_parameter_set_name (GraphsFittingParameter* self,
                                        const gchar* value);
VALA_EXTERN gdouble graphs_fitting_parameter_get_initial (GraphsFittingParameter* self);
VALA_EXTERN void graphs_fitting_parameter_set_initial (GraphsFittingParameter* self,
                                           gdouble value);
VALA_EXTERN const gchar* graphs_fitting_parameter_get_lower_bound (GraphsFittingParameter* self);
VALA_EXTERN void graphs_fitting_parameter_set_lower_bound (GraphsFittingParameter* self,
                                               const gchar* value);
VALA_EXTERN const gchar* graphs_fitting_parameter_get_upper_bound (GraphsFittingParameter* self);
VALA_EXTERN void graphs_fitting_parameter_set_upper_bound (GraphsFittingParameter* self,
                                               const gchar* value);
VALA_EXTERN GType graphs_curve_fitting_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsCurveFittingDialog, g_object_unref)
VALA_EXTERN void graphs_curve_fitting_dialog_setup (GraphsCurveFittingDialog* self);
VALA_EXTERN GraphsCurveFittingDialog* graphs_curve_fitting_dialog_new (void);
VALA_EXTERN GraphsCurveFittingDialog* graphs_curve_fitting_dialog_construct (GType object_type);
VALA_EXTERN AdwEntryRow* graphs_curve_fitting_dialog_get_custom_equation (GraphsCurveFittingDialog* self);
VALA_EXTERN GtkBox* graphs_curve_fitting_dialog_get_fitting_params_box (GraphsCurveFittingDialog* self);
VALA_EXTERN GtkTextView* graphs_curve_fitting_dialog_get_text_view (GraphsCurveFittingDialog* self);
VALA_EXTERN GraphsApplication* graphs_curve_fitting_dialog_get_application (GraphsCurveFittingDialog* self);
VALA_EXTERN void graphs_curve_fitting_dialog_set_application (GraphsCurveFittingDialog* self,
                                                  GraphsApplication* value);
VALA_EXTERN GSettings* graphs_curve_fitting_dialog_get_settings (GraphsCurveFittingDialog* self);
VALA_EXTERN const gchar* graphs_curve_fitting_dialog_get_equation_string (GraphsCurveFittingDialog* self);
VALA_EXTERN void graphs_curve_fitting_dialog_set_equation_string (GraphsCurveFittingDialog* self,
                                                      const gchar* value);
VALA_EXTERN GraphsCanvas* graphs_curve_fitting_dialog_get_canvas (GraphsCurveFittingDialog* self);
VALA_EXTERN void graphs_curve_fitting_dialog_set_canvas (GraphsCurveFittingDialog* self,
                                             GraphsCanvas* value);
VALA_EXTERN GType graphs_fitting_parameter_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsFittingParameterBox, g_object_unref)
VALA_EXTERN GraphsFittingParameterBox* graphs_fitting_parameter_box_new (GraphsFittingParameter* param);
VALA_EXTERN GraphsFittingParameterBox* graphs_fitting_parameter_box_construct (GType object_type,
                                                                   GraphsFittingParameter* param);
VALA_EXTERN void graphs_fitting_parameter_box_set_bounds_visible (GraphsFittingParameterBox* self,
                                                      gboolean visible);
VALA_EXTERN AdwEntryRow* graphs_fitting_parameter_box_get_initial (GraphsFittingParameterBox* self);
VALA_EXTERN AdwEntryRow* graphs_fitting_parameter_box_get_upper_bound (GraphsFittingParameterBox* self);
VALA_EXTERN AdwEntryRow* graphs_fitting_parameter_box_get_lower_bound (GraphsFittingParameterBox* self);
VALA_EXTERN gboolean* graphs_data_get_used_positions (GraphsData* self,
                                          gint* result_length1);
VALA_EXTERN void graphs_data_set_used_positions (GraphsData* self,
                                     gboolean a,
                                     gboolean b,
                                     gboolean c,
                                     gboolean d);
VALA_EXTERN GraphsData* graphs_data_new (void);
VALA_EXTERN GraphsData* graphs_data_construct (GType object_type);
VALA_EXTERN GSettings* graphs_data_get_settings (GraphsData* self);
VALA_EXTERN void graphs_data_set_settings (GraphsData* self,
                               GSettings* value);
VALA_EXTERN GType graphs_figure_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsFigureSettings, g_object_unref)
VALA_EXTERN GraphsFigureSettings* graphs_data_get_figure_settings (GraphsData* self);
VALA_EXTERN void graphs_data_set_figure_settings (GraphsData* self,
                                      GraphsFigureSettings* value);
VALA_EXTERN gboolean graphs_data_get_can_undo (GraphsData* self);
VALA_EXTERN void graphs_data_set_can_undo (GraphsData* self,
                               gboolean value);
VALA_EXTERN gboolean graphs_data_get_can_redo (GraphsData* self);
VALA_EXTERN void graphs_data_set_can_redo (GraphsData* self,
                               gboolean value);
VALA_EXTERN gboolean graphs_data_get_can_view_back (GraphsData* self);
VALA_EXTERN void graphs_data_set_can_view_back (GraphsData* self,
                                    gboolean value);
VALA_EXTERN gboolean graphs_data_get_can_view_forward (GraphsData* self);
VALA_EXTERN void graphs_data_set_can_view_forward (GraphsData* self,
                                       gboolean value);
VALA_EXTERN GFile* graphs_data_get_file (GraphsData* self);
VALA_EXTERN void graphs_data_set_file (GraphsData* self,
                           GFile* value);
VALA_EXTERN gboolean graphs_data_get_unsaved (GraphsData* self);
VALA_EXTERN void graphs_data_set_unsaved (GraphsData* self,
                              gboolean value);
VALA_EXTERN GType graphs_export_figure_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsExportFigureDialog, g_object_unref)
VALA_EXTERN GraphsExportFigureDialog* graphs_export_figure_dialog_new (GraphsApplication* application);
VALA_EXTERN GraphsExportFigureDialog* graphs_export_figure_dialog_construct (GType object_type,
                                                                 GraphsApplication* application);
VALA_EXTERN AdwSpinRow* graphs_export_figure_dialog_get_dpi (GraphsExportFigureDialog* self);
VALA_EXTERN AdwSwitchRow* graphs_export_figure_dialog_get_transparent (GraphsExportFigureDialog* self);
VALA_EXTERN AdwComboRow* graphs_export_figure_dialog_get_file_format (GraphsExportFigureDialog* self);
VALA_EXTERN GraphsFigureSettings* graphs_figure_settings_new (GSettings* settings);
VALA_EXTERN GraphsFigureSettings* graphs_figure_settings_construct (GType object_type,
                                                        GSettings* settings);
VALA_EXTERN gdouble* graphs_figure_settings_get_limits (GraphsFigureSettings* self,
                                            gint* result_length1);
VALA_EXTERN void graphs_figure_settings_set_limits (GraphsFigureSettings* self,
                                        gdouble* limits,
                                        gint limits_length1);
VALA_EXTERN void graphs_figure_settings_set_selection_range (GraphsFigureSettings* self,
                                                 gdouble minimum,
                                                 gdouble maximum);
VALA_EXTERN const gchar* graphs_figure_settings_get_title (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_title (GraphsFigureSettings* self,
                                       const gchar* value);
VALA_EXTERN const gchar* graphs_figure_settings_get_bottom_label (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_bottom_label (GraphsFigureSettings* self,
                                              const gchar* value);
VALA_EXTERN const gchar* graphs_figure_settings_get_left_label (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_left_label (GraphsFigureSettings* self,
                                            const gchar* value);
VALA_EXTERN const gchar* graphs_figure_settings_get_top_label (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_top_label (GraphsFigureSettings* self,
                                           const gchar* value);
VALA_EXTERN const gchar* graphs_figure_settings_get_right_label (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_right_label (GraphsFigureSettings* self,
                                             const gchar* value);
VALA_EXTERN gint graphs_figure_settings_get_bottom_scale (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_bottom_scale (GraphsFigureSettings* self,
                                              gint value);
VALA_EXTERN gint graphs_figure_settings_get_left_scale (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_left_scale (GraphsFigureSettings* self,
                                            gint value);
VALA_EXTERN gint graphs_figure_settings_get_top_scale (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_top_scale (GraphsFigureSettings* self,
                                           gint value);
VALA_EXTERN gint graphs_figure_settings_get_right_scale (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_right_scale (GraphsFigureSettings* self,
                                             gint value);
VALA_EXTERN gboolean graphs_figure_settings_get_legend (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_legend (GraphsFigureSettings* self,
                                        gboolean value);
VALA_EXTERN gint graphs_figure_settings_get_legend_position (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_legend_position (GraphsFigureSettings* self,
                                                 gint value);
VALA_EXTERN gboolean graphs_figure_settings_get_use_custom_style (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_use_custom_style (GraphsFigureSettings* self,
                                                  gboolean value);
VALA_EXTERN const gchar* graphs_figure_settings_get_custom_style (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_custom_style (GraphsFigureSettings* self,
                                              const gchar* value);
VALA_EXTERN gboolean graphs_figure_settings_get_hide_unselected (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_hide_unselected (GraphsFigureSettings* self,
                                                 gboolean value);
VALA_EXTERN gdouble graphs_figure_settings_get_min_bottom (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_min_bottom (GraphsFigureSettings* self,
                                            gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_max_bottom (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_max_bottom (GraphsFigureSettings* self,
                                            gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_min_left (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_min_left (GraphsFigureSettings* self,
                                          gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_max_left (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_max_left (GraphsFigureSettings* self,
                                          gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_min_top (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_min_top (GraphsFigureSettings* self,
                                         gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_max_top (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_max_top (GraphsFigureSettings* self,
                                         gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_min_right (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_min_right (GraphsFigureSettings* self,
                                           gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_max_right (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_max_right (GraphsFigureSettings* self,
                                           gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_min_selected (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_min_selected (GraphsFigureSettings* self,
                                              gdouble value);
VALA_EXTERN gdouble graphs_figure_settings_get_max_selected (GraphsFigureSettings* self);
VALA_EXTERN void graphs_figure_settings_set_max_selected (GraphsFigureSettings* self,
                                              gdouble value);
VALA_EXTERN GType graphs_figure_settings_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsFigureSettingsDialog, g_object_unref)
VALA_EXTERN void graphs_figure_settings_dialog_setup (GraphsFigureSettingsDialog* self,
                                          const gchar* highlighted);
VALA_EXTERN void graphs_figure_settings_dialog_add_toast_string (GraphsFigureSettingsDialog* self,
                                                     const gchar* msg);
VALA_EXTERN GraphsFigureSettingsDialog* graphs_figure_settings_dialog_new (void);
VALA_EXTERN GraphsFigureSettingsDialog* graphs_figure_settings_dialog_construct (GType object_type);
VALA_EXTERN AdwNavigationView* graphs_figure_settings_dialog_get_navigation_view (GraphsFigureSettingsDialog* self);
VALA_EXTERN GraphsApplication* graphs_figure_settings_dialog_get_application (GraphsFigureSettingsDialog* self);
VALA_EXTERN void graphs_figure_settings_dialog_set_application (GraphsFigureSettingsDialog* self,
                                                    GraphsApplication* value);
VALA_EXTERN AdwNavigationPage* graphs_figure_settings_dialog_get_settings_page (GraphsFigureSettingsDialog* self);
VALA_EXTERN AdwNavigationPage* graphs_figure_settings_dialog_get_style_editor (GraphsFigureSettingsDialog* self);
VALA_EXTERN void graphs_figure_settings_dialog_set_style_editor (GraphsFigureSettingsDialog* self,
                                                     AdwNavigationPage* value);
VALA_EXTERN GraphsFigureSettings* graphs_figure_settings_dialog_get_figure_settings (GraphsFigureSettingsDialog* self);
VALA_EXTERN GType graphs_import_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsImportDialog, g_object_unref)
VALA_EXTERN GraphsImportDialog* graphs_import_dialog_new (GraphsApplication* application,
                                              gchar** modes,
                                              gint modes_length1);
VALA_EXTERN GraphsImportDialog* graphs_import_dialog_construct (GType object_type,
                                                    GraphsApplication* application,
                                                    gchar** modes,
                                                    gint modes_length1);
VALA_EXTERN GType graphs_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsItem, g_object_unref)
VALA_EXTERN void graphs_item_get_rgba (GraphsItem* self,
                           GdkRGBA* result);
VALA_EXTERN void graphs_item_set_rgba (GraphsItem* self,
                           GdkRGBA* rgba);
VALA_EXTERN GraphsItem* graphs_item_new (void);
VALA_EXTERN GraphsItem* graphs_item_construct (GType object_type);
VALA_EXTERN const gchar* graphs_item_get_name (GraphsItem* self);
VALA_EXTERN void graphs_item_set_name (GraphsItem* self,
                           const gchar* value);
VALA_EXTERN const gchar* graphs_item_get_color (GraphsItem* self);
VALA_EXTERN void graphs_item_set_color (GraphsItem* self,
                            const gchar* value);
VALA_EXTERN gfloat graphs_item_get_alpha (GraphsItem* self);
VALA_EXTERN void graphs_item_set_alpha (GraphsItem* self,
                            gfloat value);
VALA_EXTERN gboolean graphs_item_get_selected (GraphsItem* self);
VALA_EXTERN void graphs_item_set_selected (GraphsItem* self,
                               gboolean value);
VALA_EXTERN const gchar* graphs_item_get_xlabel (GraphsItem* self);
VALA_EXTERN void graphs_item_set_xlabel (GraphsItem* self,
                             const gchar* value);
VALA_EXTERN const gchar* graphs_item_get_ylabel (GraphsItem* self);
VALA_EXTERN void graphs_item_set_ylabel (GraphsItem* self,
                             const gchar* value);
VALA_EXTERN gint graphs_item_get_xposition (GraphsItem* self);
VALA_EXTERN void graphs_item_set_xposition (GraphsItem* self,
                                gint value);
VALA_EXTERN gint graphs_item_get_yposition (GraphsItem* self);
VALA_EXTERN void graphs_item_set_yposition (GraphsItem* self,
                                gint value);
VALA_EXTERN const gchar* graphs_item_get_uuid (GraphsItem* self);
VALA_EXTERN void graphs_item_set_uuid (GraphsItem* self,
                           const gchar* value);
VALA_EXTERN GType graphs_inline_stack_switcher_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsInlineStackSwitcher, g_object_unref)
VALA_EXTERN GraphsInlineStackSwitcher* graphs_inline_stack_switcher_new (void);
VALA_EXTERN GraphsInlineStackSwitcher* graphs_inline_stack_switcher_construct (GType object_type);
VALA_EXTERN GtkStack* graphs_inline_stack_switcher_get_stack (GraphsInlineStackSwitcher* self);
VALA_EXTERN void graphs_inline_stack_switcher_set_stack (GraphsInlineStackSwitcher* self,
                                             GtkStack* value);
VALA_EXTERN GType graphs_item_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsItemBox, g_object_unref)
VALA_EXTERN void graphs_item_box_setup (GraphsItemBox* self);
VALA_EXTERN GraphsItemBox* graphs_item_box_new (void);
VALA_EXTERN GraphsItemBox* graphs_item_box_construct (GType object_type);
VALA_EXTERN GtkCheckButton* graphs_item_box_get_check_button (GraphsItemBox* self);
VALA_EXTERN GraphsApplication* graphs_item_box_get_application (GraphsItemBox* self);
VALA_EXTERN void graphs_item_box_set_application (GraphsItemBox* self,
                                      GraphsApplication* value);
VALA_EXTERN GraphsItem* graphs_item_box_get_item (GraphsItemBox* self);
VALA_EXTERN void graphs_item_box_set_item (GraphsItemBox* self,
                               GraphsItem* value);
VALA_EXTERN gint graphs_item_box_get_index (GraphsItemBox* self);
VALA_EXTERN void graphs_item_box_set_index (GraphsItemBox* self,
                                gint value);
VALA_EXTERN GtkGestureClick* graphs_item_box_get_click_gesture (GraphsItemBox* self);
VALA_EXTERN GtkDragSource* graphs_item_box_get_drag_source (GraphsItemBox* self);
VALA_EXTERN GtkDropTarget* graphs_item_box_get_drop_target (GraphsItemBox* self);
VALA_EXTERN GType graphs_smoothen_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsSmoothenDialog, g_object_unref)
VALA_EXTERN GraphsSmoothenDialog* graphs_smoothen_dialog_new (GraphsApplication* application);
VALA_EXTERN GraphsSmoothenDialog* graphs_smoothen_dialog_construct (GType object_type,
                                                        GraphsApplication* application);
VALA_EXTERN AdwSpinRow* graphs_smoothen_dialog_get_savgol_window (GraphsSmoothenDialog* self);
VALA_EXTERN AdwSpinRow* graphs_smoothen_dialog_get_savgol_polynomial (GraphsSmoothenDialog* self);
VALA_EXTERN AdwSpinRow* graphs_smoothen_dialog_get_moving_average_box (GraphsSmoothenDialog* self);
VALA_EXTERN GType graphs_style_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsStyle, g_object_unref)
VALA_EXTERN gint graphs_style_cmp (GraphsStyle* a,
                       GraphsStyle* b);
VALA_EXTERN gchar** graphs_style_manager_load_system_styles (GraphsStyleManager* self,
                                                 const gchar* system_style,
                                                 gint* result_length1);
VALA_EXTERN GraphsStyle* graphs_style_manager_get_selected_style (GraphsStyleManager* self);
VALA_EXTERN void graphs_style_manager_setup_bindings (GraphsStyleManager* self,
                                          GraphsFigureSettings* figure_settings);
VALA_EXTERN gchar** graphs_style_manager_list_stylenames (GraphsStyleManager* self,
                                              gint* result_length1);
VALA_EXTERN GraphsStyleManager* graphs_style_manager_new (void);
VALA_EXTERN GraphsStyleManager* graphs_style_manager_construct (GType object_type);
VALA_EXTERN GraphsApplication* graphs_style_manager_get_application (GraphsStyleManager* self);
VALA_EXTERN void graphs_style_manager_set_application (GraphsStyleManager* self,
                                           GraphsApplication* value);
VALA_EXTERN gboolean graphs_style_manager_get_use_custom_style (GraphsStyleManager* self);
VALA_EXTERN void graphs_style_manager_set_use_custom_style (GraphsStyleManager* self,
                                                gboolean value);
VALA_EXTERN const gchar* graphs_style_manager_get_custom_style (GraphsStyleManager* self);
VALA_EXTERN void graphs_style_manager_set_custom_style (GraphsStyleManager* self,
                                            const gchar* value);
VALA_EXTERN GtkSingleSelection* graphs_style_manager_get_selection_model (GraphsStyleManager* self);
VALA_EXTERN void graphs_style_manager_set_selection_model (GraphsStyleManager* self,
                                               GtkSingleSelection* value);
VALA_EXTERN GFile* graphs_style_manager_get_style_dir (GraphsStyleManager* self);
VALA_EXTERN void graphs_style_manager_set_style_dir (GraphsStyleManager* self,
                                         GFile* value);
VALA_EXTERN const gchar* graphs_style_manager_get_selected_stylename (GraphsStyleManager* self);
VALA_EXTERN void graphs_style_manager_set_selected_stylename (GraphsStyleManager* self,
                                                  const gchar* value);
VALA_EXTERN GraphsStyle* graphs_style_new (const gchar* name,
                               GFile* file,
                               GdkTexture* preview,
                               gboolean mutable);
VALA_EXTERN GraphsStyle* graphs_style_construct (GType object_type,
                                     const gchar* name,
                                     GFile* file,
                                     GdkTexture* preview,
                                     gboolean mutable);
VALA_EXTERN const gchar* graphs_style_get_name (GraphsStyle* self);
VALA_EXTERN void graphs_style_set_name (GraphsStyle* self,
                            const gchar* value);
VALA_EXTERN GdkTexture* graphs_style_get_preview (GraphsStyle* self);
VALA_EXTERN void graphs_style_set_preview (GraphsStyle* self,
                               GdkTexture* value);
VALA_EXTERN GFile* graphs_style_get_file (GraphsStyle* self);
VALA_EXTERN void graphs_style_set_file (GraphsStyle* self,
                            GFile* value);
VALA_EXTERN gboolean graphs_style_get_mutable (GraphsStyle* self);
VALA_EXTERN void graphs_style_set_mutable (GraphsStyle* self,
                               gboolean value);
VALA_EXTERN gboolean graphs_style_get_light (GraphsStyle* self);
VALA_EXTERN void graphs_style_set_light (GraphsStyle* self,
                             gboolean value);
VALA_EXTERN GType graphs_add_style_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsAddStyleDialog, g_object_unref)
VALA_EXTERN GraphsAddStyleDialog* graphs_add_style_dialog_new (GraphsStyleManager* style_manager,
                                                   GtkWidget* parent);
VALA_EXTERN GraphsAddStyleDialog* graphs_add_style_dialog_construct (GType object_type,
                                                         GraphsStyleManager* style_manager,
                                                         GtkWidget* parent);
VALA_EXTERN GType graphs_transform_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GraphsTransformDialog, g_object_unref)
VALA_EXTERN GraphsTransformDialog* graphs_transform_dialog_new (GraphsApplication* application);
VALA_EXTERN GraphsTransformDialog* graphs_transform_dialog_construct (GType object_type,
                                                          GraphsApplication* application);
VALA_EXTERN void graphs_tools_bind_settings_to_widgets (GSettings* settings,
                                            GtkWidget* parent);
VALA_EXTERN void graphs_tools_reset_settings (GSettings* settings);
VALA_EXTERN void graphs_tools_hex_to_rgba (const gchar* hex,
                               GdkRGBA* result);
VALA_EXTERN gchar* graphs_tools_rgba_to_hex (GdkRGBA* rgba);
VALA_EXTERN gdouble graphs_tools_get_luminance_from_hex (const gchar* hex);
VALA_EXTERN gdouble graphs_tools_get_luminance_from_rgba (GdkRGBA* rgba);
VALA_EXTERN gdouble graphs_tools_get_contrast (GdkRGBA* bg_color,
                                   GdkRGBA* fg_color);
VALA_EXTERN gchar* graphs_tools_shorten_label (const gchar* label,
                                   guint max_length);
VALA_EXTERN gchar* graphs_tools_get_duplicate_string (const gchar* original,
                                          gchar** used,
                                          gint used_length1);
VALA_EXTERN GFile* graphs_tools_get_config_directory (GError** error);
VALA_EXTERN gchar* graphs_tools_get_filename (GFile* file);
VALA_EXTERN GObject* graphs_tools_build_dialog (const gchar* name);
VALA_EXTERN void graphs_tools_open_file_location (GFile* file);
VALA_EXTERN GraphsWindow* graphs_window_new (GraphsApplication* application);
VALA_EXTERN GraphsWindow* graphs_window_construct (GType object_type,
                                       GraphsApplication* application);
VALA_EXTERN void graphs_window_add_toast (GraphsWindow* self,
                              AdwToast* toast);
VALA_EXTERN void graphs_window_add_toast_string (GraphsWindow* self,
                                     const gchar* title);
VALA_EXTERN void graphs_window_add_toast_string_with_file (GraphsWindow* self,
                                               const gchar* title,
                                               GFile* file);
VALA_EXTERN void graphs_window_update_view_menu (GraphsWindow* self);
VALA_EXTERN GtkButton* graphs_window_get_undo_button (GraphsWindow* self);
VALA_EXTERN GtkButton* graphs_window_get_redo_button (GraphsWindow* self);
VALA_EXTERN GtkButton* graphs_window_get_view_back_button (GraphsWindow* self);
VALA_EXTERN GtkButton* graphs_window_get_view_forward_button (GraphsWindow* self);
VALA_EXTERN GtkToggleButton* graphs_window_get_pan_button (GraphsWindow* self);
VALA_EXTERN GtkButton* graphs_window_get_shift_button (GraphsWindow* self);
VALA_EXTERN GtkButton* graphs_window_get_cut_button (GraphsWindow* self);
VALA_EXTERN GtkEntry* graphs_window_get_translate_x_entry (GraphsWindow* self);
VALA_EXTERN GtkEntry* graphs_window_get_translate_y_entry (GraphsWindow* self);
VALA_EXTERN GtkEntry* graphs_window_get_multiply_x_entry (GraphsWindow* self);
VALA_EXTERN GtkEntry* graphs_window_get_multiply_y_entry (GraphsWindow* self);
VALA_EXTERN GtkButton* graphs_window_get_translate_x_button (GraphsWindow* self);
VALA_EXTERN GtkButton* graphs_window_get_translate_y_button (GraphsWindow* self);
VALA_EXTERN GtkButton* graphs_window_get_multiply_x_button (GraphsWindow* self);
VALA_EXTERN GtkButton* graphs_window_get_multiply_y_button (GraphsWindow* self);
VALA_EXTERN GtkListBox* graphs_window_get_item_list (GraphsWindow* self);
VALA_EXTERN AdwOverlaySplitView* graphs_window_get_split_view (GraphsWindow* self);
VALA_EXTERN AdwWindowTitle* graphs_window_get_content_title (GraphsWindow* self);
VALA_EXTERN void graphs_window_set_mode (GraphsWindow* self,
                             gint value);
VALA_EXTERN GraphsCanvas* graphs_window_get_canvas (GraphsWindow* self);
VALA_EXTERN void graphs_window_set_canvas (GraphsWindow* self,
                               GraphsCanvas* value);
VALA_EXTERN GtkCssProvider* graphs_window_get_headerbar_provider (GraphsWindow* self);

VALA_EXTERN const gchar* GRAPHS_LIMIT_NAMES[8];
VALA_EXTERN const gchar* GRAPHS_DIRECTION_NAMES[4];
VALA_EXTERN const gchar* GRAPHS_ACTION_NAMES[23];

G_END_DECLS

#endif
