/* misc.c generated by valac 0.56.19, the Vala compiler
 * generated from misc.vala, do not modify */

/* SPDX-License-Identifier: GPL-3.0-or-later*/

#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include "graphs.h"

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

const gchar* GRAPHS_LIMIT_NAMES[8] = {"min-bottom", "max-bottom", "min-top", "max-top", "min-left", "max-left", "min-right", "max-right"};
const gchar* GRAPHS_DIRECTION_NAMES[4] = {"bottom", "top", "left", "right"};
const gchar* GRAPHS_ACTION_NAMES[23] = {"quit", "help", "about", "figure_settings", "add_data", "add_equation", "select_all", "select_none", "undo", "redo", "optimize_limits", "view_back", "view_forward", "export_data", "export_figure", "new_project", "save_project", "save_project_as", "smoothen_settings", "open_project", "delete_selected", "zoom_in", "zoom_out"};

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

